==> Pyrogram-0.13.0-py3-none-any.whl: pyrogram/api/types/photo_size_empty.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class PhotoSizeEmpty(Object):
    """Attributes:
        ID: ``0x0e17e23c``

    Parameters:
        type: ``str``
    """

    __slots__ = ["type"]

    ID = 0x0e17e23c
    QUALNAME = "types.PhotoSizeEmpty"

    def __init__(self, *, type: str):
        self.type = type  # string

    @staticmethod
    def read(b: BytesIO, *args) -> "PhotoSizeEmpty":
        # No flags
        
        type = String.read(b)
        
        return PhotoSizeEmpty(type=type)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(String(self.type))
        
        return b.getvalue()

==> Pyrogram-0.15.1-py3-none-any.whl: pyrogram/api/types/photo_size_empty.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class PhotoSizeEmpty(TLObject):
    """Attributes:
        LAYER: ``102``

    Attributes:
        ID: ``0x0e17e23c``

    Parameters:
        type: ``str``
    """

    __slots__ = ["type"]

    ID = 0x0e17e23c
    QUALNAME = "types.PhotoSizeEmpty"

    def __init__(self, *, type: str):
        self.type = type  # string

    @staticmethod
    def read(b: BytesIO, *args) -> "PhotoSizeEmpty":
        # No flags
        
        type = String.read(b)
        
        return PhotoSizeEmpty(type=type)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(String(self.type))
        
        return b.getvalue()
